@@ -87,6 +87,7 @@ class Reply:
             "size",
             "source_url",
             "uuid",
+            "seen_by",
         ]:
             if key not in kwargs:
                 AttributeError("Missing key {}".format(key))
@@ -125,12 +126,16 @@ class Submission:
             "source_url",
             "submission_url",
             "uuid",
+            "seen_by",
         ]:
             if key not in kwargs:
                 AttributeError("Missing key {}".format(key))
             setattr(self, key, kwargs[key])
         _, self.source_uuid = self.source_url.rsplit("/", 1)
 
+    def is_file(self) -> bool:
+        return self.filename.endswith("doc.gz.gpg") or self.filename.endswith("doc.zip.gpg")
+
 
 class Source:
     """
@@ -177,3 +182,26 @@ class Source:
             if key not in kwargs:
                 AttributeError("Missing key {}".format(key))
             setattr(self, key, kwargs[key])
+
+
+class User:
+    """
+    This class represents a user (journalist or admin) of the Journalist
+    Interface.
+    """
+
+    def __init__(self, **kwargs) -> None:  # type: ignore
+        self.first_name = ""  # type: str
+        self.last_name = ""  # type: str
+        self.username = ""  # type: str
+        self.uuid = ""  # type: str
+
+        for key in [
+            "first_name",
+            "last_name",
+            "username",
+            "uuid",
+        ]:
+            if key not in kwargs:
+                AttributeError("Missing key {}".format(key))
+            setattr(self, key, kwargs[key])
